iconv: Library for language/country-dependent character encodings
=================================================================

Description
-----------

GNU libiconv is a library that is used to enable different languages,
with different characters to be handled properly.

License
-------

-  GPL 3 and LGPL 3. So we can safely link against the library in Sage.


Upstream Contact
----------------

-  http://www.gnu.org/software/libiconv/
-  Bug reports to bug-gnu-libiconv@gnu.org
